com.timezynk.assembly-line


assembly-lineclj

(assembly-line steps & {:keys [environment wrapper-f execution-wrapper-f]})

AssemblyLineExecutecljprotocol

add-stationsclj

(add-stations this placement new-stations)
(add-stations this placement target-station new-stations)

Inject a step :before or :after another step, or :replace it.

Inject a step :before or :after another step, or :replace it.

execute!clj

(execute! this)
(execute! this pause-at)

Execute steps from current position until finished or if key is provided, until that step is reached. The flag async? switches between synchronous and asynchronous execution, and is true by default.

Execute steps from current position until finished
or if key is provided, until that step is reached. The flag async?
switches between synchronous and asynchronous execution, and is
true by default.

prepareclj

(prepare this arg)

Prepare a recipe for execution with provided value as the initial argument.

Prepare a recipe for execution with provided value as the initial argument.

wrapclj

(wrap wrapper-f)

cljdoc builds & hosts documentation for Clojure/Script libraries